==> openshift-model-operatorhub-5.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorGroupBuilder extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupBuilder>{
  public OperatorGroupBuilder() {
    this(false);
  }
  public OperatorGroupBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorGroup(), validationEnabled);
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorGroup(), validationEnabled);
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup instance) {
    this(fluent, instance, false);
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup instance) {
    this(instance,false);
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup build() {
    OperatorGroup buildable = new OperatorGroup(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorGroupBuilder that = (OperatorGroupBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorGroupBuilder extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupBuilder>{
  public OperatorGroupBuilder() {
    this(false);
  }
  public OperatorGroupBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorGroup(), validationEnabled);
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorGroup(), validationEnabled);
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup instance) {
    this(fluent, instance, false);
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup instance) {
    this(instance,false);
  }
  public OperatorGroupBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroup build() {
    OperatorGroup buildable = new OperatorGroup(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorGroupBuilder that = (OperatorGroupBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
